summaryrefslogtreecommitdiff
path: root/plugins/python/python.plugin.zsh
diff options
context:
space:
mode:
Diffstat (limited to 'plugins/python/python.plugin.zsh')
-rw-r--r--plugins/python/python.plugin.zsh5
1 files changed, 3 insertions, 2 deletions
diff --git a/plugins/python/python.plugin.zsh b/plugins/python/python.plugin.zsh
index a10c06fd3..950b0e01a 100644
--- a/plugins/python/python.plugin.zsh
+++ b/plugins/python/python.plugin.zsh
@@ -1,14 +1,15 @@
# Find python file
alias pyfind='find . -name "*.py"'
# Remove python compiled byte-code in either current directory or in a
# list of specified directories
function pyclean() {
ZSH_PYCLEAN_PLACES=${*:-'.'}
find ${ZSH_PYCLEAN_PLACES} -type f -name "*.py[co]" -delete
find ${ZSH_PYCLEAN_PLACES} -type d -name "__pycache__" -delete
+ find ${ZSH_PYCLEAN_PLACES} -type d -name ".mypy_cache" -delete
}
# Grep among .py files
-alias pygrep='grep --include="*.py"'
+alias pygrep='grep -r --include="*.py"'
@@ -1,14 +1,15 @@
# Find python file
alias pyfind='find . -name "*.py"'
-# Remove python compiled byte-code in either current directory or in a
+# Remove python compiled byte-code and mypy cache in either current directory or in a
# list of specified directories
function pyclean() {